Products.ZMySQLDA
=================

.. image:: https://github.com/zopefoundation/Products.ZMySQLDA/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/zopefoundation/Products.ZMySQLDA/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/Products.ZMySQLDA/badge.svg?branch=master
   :target: https://coveralls.io/github/zopefoundation/Products.ZMySQLDA?branch=master

.. image:: https://readthedocs.org/projects/zmysqlda/badge/?version=latest
   :target: https://zmysqlda.readthedocs.io
   :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/Products.ZMySQLDA.svg
   :target: https://pypi.org/project/Products.ZMySQLDA/
   :alt: Latest stable release on PyPI

.. image:: https://img.shields.io/pypi/pyversions/Products.ZMySQLDA.svg
   :target: https://pypi.org/project/Products.ZMySQLDA/
   :alt: Stable release supported Python versions

This is the MySQL database adapter product for Zope.

Compatibility
-------------

* ``Zope`` 5 under Python 3.7 and higher.

* MySQL versions 3.22 and later including MariaDB. You need version 4.1
  or higher for unicode support.
